# merry

[![Build status](https://github.com/miguelgrinberg/merry/workflows/build/badge.svg)](https://github.com/miguelgrinberg/merry/actions) [![codecov](https://codecov.io/gh/miguelgrinberg/merry/branch/main/graph/badge.svg)](https://codecov.io/gh/miguelgrinberg/merry)

Decorator based error handling for Python

## Resources

- [Documentation](http://merry-py.readthedocs.io/en/latest/)
- [PyPI](https://pypi.python.org/pypi/merry)
- [Change Log](https://github.com/miguelgrinberg/merry/blob/main/CHANGES.md)

